﻿/*
                BS_Ørganiz_StartupScriptBuilder
                
    ***** Ce script permet de générer un "Startup" script qui organisera le paneau projet automatiquement au lancement d'after effects *****
    
    Possibilité d'enregistrer jusque 5 modèles d'organisation différents.
    
    Seulement pour Windows.
    
    Développé sous Windows 7 Pro (fr).
    
    Testé avec les versions After Effects (fr):
        _  11 (CS6)
        _ 13 (CC2014)
        _ 13.5 + maj (CC2015)
        _ 14 (CC2017)
        _ 14.2.1.34 (CC2017.2)
        
    Version 2.2:
        _ Dernière mise à jour : 23/10/2017
            _ Ajout d'une balise au cas où l'option d'autorisation d'ecriture des scripts ne serait pas active.
            _ Traduction pour les versions en_US d'After Effects.
        
    Version 2.1:
        _  Dernière mise à jour : 11/10/2017
             _ Les charactères spéciaux dans les noms de dossiers et de modèles ne causent plus le crash du Startup Script.
        
    Version 2:
        _ Dernière mise à jour : 20/09/2017
        *** Mises à jour faites principalement pour le partage de l'outil. ***
            _ Nouvelle interface globale
            _ Possibilité de mémoriser plusieurs modèles


Par Simon Salord
(BS pour Black Solid)

J'espère que ce script vous sera autant utile qu'il l'est pour moi!
*/

{
function KeepOrganiz_StartupScriptBuilder (thisObj)
{
    var scriptName = "BS_Ørganiz_StartupScripteur";
    var scriptVersion = "_v2";
    
// globals pour la trad

    var organiz_SSB_GlobalsDatas = new Object();
    organiz_SSB_GlobalsDatas.lang = app.isoLanguage.split("_")[0];
    organiz_SSB_GlobalsDatas.wrongPath_str = {
        fr: "Impossible d'executer le script: \"BS_Ørganiz_StartupScripteur\".\n"+ "\n"+
        "Celui-ci il doit être installé dans le dossier: \"Scripts\" correspondant à votre version After Effects...\n"+
        "└› ex: \"C:\\Program Files\\Adobe\\Adobe After Effects CC 2017\\Support Files\\Scripts\"",
        en: "Impossible to execute the script: \"BS_Ørganiz_StartupScripteur\".\n"+ "\n"+
        "This one must be installed in the After Effects's script folder directory.\n"+
        "└› ex: \"C:\\Program Files\\Adobe\\Adobe After Effects CC 2017\\Support Files\\Scripts\""
    };
    organiz_SSB_GlobalsDatas.sttx_mod1_str = {
        fr: "favori",
        en: "favorite"
    };
    organiz_SSB_GlobalsDatas.memoHelpTip_str = {
        fr: "Mémoriser le modèle de projet.",
        en: "Momorize the project template."
    };
    organiz_SSB_GlobalsDatas.verifyHelpTip_str = {
        fr: "Visualiser le modèle mémorisé.",
        en: "Visualize the project template."
    };
    organiz_SSB_GlobalsDatas.alertMsg_modName_str = {
        fr: "Veuillez donner un nom au modèle de projet.",
        en: "Please give a name to the project template."
    };
    organiz_SSB_GlobalsDatas.alertMsg_emptyMod_str = {
        fr: "Le modèle est vide...",
        en: "This template is empty..."
    };
    organiz_SSB_GlobalsDatas.alertMsg_noModSaved_str = {
        fr: "Il n'y a pas de modèle mémorisé à cet emplacement.",
        en: "No template memorized here."
    };
    organiz_SSB_GlobalsDatas.alertMsg_cantPerformScripting_str = {
        fr: "Oups !!!\nVérifiez que tous les modèles actifs soient bien nommés et/ou qu'ils aient été bien mémorisés.",
        en: "Oops !!!\nCheck that all active models are well named and/or have been memorized."
    };
    organiz_SSB_GlobalsDatas.alertMsg_scriptNeedToWrite_str = {
        fr:"BS_Ørganiz_StartupScripteur a besoin de pouvoir écrire sur le disque pour générer le startup script \"BS_Ørganiz_v2.jsx\".\n\n"+
        "Veuillez cocher la case: \"Autoriser les scripts à écrire des fichiers et à accéder au réseau\" dans les préférences générales.",
        en: "BS_Ørganiz_StartupScripteur needs to be able to write on your disk to generate the startup script \"BS_Ørganiz_v2.jsx\".\n\n"+
         "Please check the box:\" Allow scripts to write files and access network \"in the general preferences."
    };
    organiz_SSB_GlobalsDatas.alertMsg_cantCreatFile_str = {
        fr: "Le fichier \"BS_Ørganiz_v2.jsx\" n'a pas pû être créée.\n Veuillez vérifier les droits administrateur avant de recommencer.",
        en: "The file \"BS_Ørganiz_v2.jsx\" could not be created.\n Please check the administrator's rights before starting over again."
    };
    organiz_SSB_GlobalsDatas.alertMsg_fileStrError_str = {
        fr: "Erreur inattendue...\n\n"+
            "Le contenu du fichier \"BS_Ørganiz_v2.jsx\" n'est pas conforme.\n"+
            "Supprimer le et rééssayez en veillant à éviter tous caractères spéciaux.",
        en: "Unexpected error...\n\n"+
              "The contents of the file \"BS_Ørganiz_v2.jsx\" is not conformed.\n"+
              "Please delete it and try again by avoiding specials characters. "
    };
    organiz_SSB_GlobalsDatas.alertMsg_info_str = {
        fr: scriptName+scriptVersion+"\n"+
        "Par Simon Salord\n"+
        "http://nowisvalvert.wix.com/simonsalord\n"+
        "\n"+
        "1: Créez un modèle d'organisation de projet directement dans le paneau Projet d'After Effects.\n"+
        "└› Attention! Chaque dossier doit avoir un nom unique.\n"+
        "\n"+
        "2: Nommer le modèle dans la fenêtre de texte éditable correspondante\nau modèle à sauvegarder.\n"+
        "\n"+
        "3: Cliquez sur le bouton ▼ correspondant pour mémoriser le modèle.\n"+
        "\n"+
        "4: Activez d'autres modèles et recommencez l'opération autant de fois que souhaité.\n"+
        "└› Possibilité de créer jusqu'à 5 modèles d'organisation.\n"+
        "\n"+
        "5: Vous pouvez vérifier à tout moment les modèles sauvegardés\nen cliquant sur le bouton Ø correspondant au modèle.\n"+
        "└› Cette action est annulable dans After Effects: Ctrl+z.\n"+
        "\n"+
        "6: Lorsque vous êtes satisfait de vos modèles d'organisation,\n"+
        "  cliquez sur le bouton \"Scripter\" pour générer le Startup Script qui sera éxecuté automatiquement à l'ouverture d'After Effects.\n",
        en: scriptName+scriptVersion+"\n"+
        "By Simon Salord\n"+
        "http://nowisvalvert.wix.com/simonsalord\n"+
        "\n"+
        "1: Create a project template in the After Effects's project panel.\n"+
        "└› Remark! Each folder must have a unique name.\n"+
        "\n"+
        "2: Name the project template in the editable text window\ncorresponding to the template to save.\n"+
        "\n"+
        "3: Click the corresponding ▼ button to memorize the template.\n"+
        "\n"+
        "4: Activate other models and repeat the operation as many times as desired.\n"+
        "└› Possibility to create up to 5 organizational models.\n"+
        "\n"+
        "5: You can check the saved templates at any time\nby clicking on the Ø button corresponding to the template.\n"+
        "└› This action can be undone in After Effects: Ctrl+z.\n"+
        "\n"+
        "6: When you are satisfy by all your templates,\n"+
        "  just click on the \"Scripter\" button to generate the Startup Script which will be automatically executed when opening After Effects.\n"
    };
    organiz_SSB_GlobalsDatas.doneTxt_str = {
        fr: "BS_Ørganiz_v2 a été créé avec succès.",
        en: "BS_Ørganiz_v2 was successfully created."
    };
    organiz_SSB_GlobalsDatas.exitOption1_str = {
        fr: "Quitter BS_Ørganiz_StartupScripteur:",
        en: "Exit BS_Ørganiz_StartupScripteur:"
    };
    organiz_SSB_GlobalsDatas.exitOption1HelpTip_str = {
        fr: "Retour dans After Effects.",
        en: "Back into After Effects."
    };
    organiz_SSB_GlobalsDatas.exitOption2_str = {
        fr: "Quitter After Effects:",
        en: "Exit After Effects:"
    };
    organiz_SSB_GlobalsDatas.exitOption2HelpTip_str = {
        fr: "Ferme After Effects sans sauvegarder.",
        en: "Close After Effects without saving."
    };
    organiz_SSB_GlobalsDatas.newScriptRes_mainQuestion_str = {
        fr: "\"\\330rganiZer LE PROJET ?\"",
        en: "\"\\330rganiZ THE PROJECT ?\""
    };
    organiz_SSB_GlobalsDatas.newScriptRes_NObut_str = {
        fr: "\"NON\"",
        en: "\"NO\""
    };
    organiz_SSB_GlobalsDatas.newScriptRes_OUIbut_str = {
        fr: "\"OUI\"",
        en: "\"YES\""
    };
// --------------------------------- fonction pour traduire en fonction de la langue d'After --------------- //
    function Organ_Trad (TXT_str)
    {
        var currStr = TXT_str[organiz_SSB_GlobalsDatas.lang];
        if (currStr == undefined) currStr = TXT_str["en"];
        return currStr;
    }
// ------------------- check si l'execution du script se fait ou non //
thisScriptName = File($.fileName);
thisScriptPath = thisScriptName.path;
pathToWrite = thisScriptPath+"/Startup";
folderToWrite = Folder (pathToWrite);

if (!folderToWrite.exists)
{
    alertMsg_wrongPath = Organ_Trad (organiz_SSB_GlobalsDatas.wrongPath_str);
    alert(alertMsg_wrongPath, scriptName+scriptVersion, errorIcon = true);
    return;
}
// ------------------- check si le script peut écrire sur le disque //
var alertMsg_scriptNeedToWrite = Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_scriptNeedToWrite_str);
if (app.preferences.getPrefAsLong('Main Pref Section','Pref_SCRIPTING_FILE_NETWORK_SECURITY') != 1)
{
    alert(alertMsg_scriptNeedToWrite, scriptName+scriptVersion);
    app.executeCommand(2359);
    if (app.preferences.getPrefAsLong('Main Pref Section','Pref_SCRIPTING_FILE_NETWORK_SECURITY') != 1)
    {
        return;
    }
}
// ------------------------------------------------------------------------------------------------ build UI --------------------------------------------------------------------------------- //

    function create_MainWin ()
    {
        var win = new Window("palette", scriptName+scriptVersion);
        win.orientation = 'row';
        win.spacing = 5;
        win.margins = [5,5,5,5];
        return win;
    }
var scriptWin = create_MainWin ();
// groupe des modèles
var mod_grp = scriptWin.add("panel");
mod_grp.orientation = 'column';
mod_grp.spacing = 2;
mod_grp.margins = [5,5,5,5];
    //---| |
    //---V
// model 1
var grp_model1 = mod_grp.add("group");
grp_model1.orientation = 'row';
grp_model1.spacing = 5;
grp_model1.margins = [0,2,0,2];
grp_model1.alignChildren = ['left', 'center'];
    var ckb_mod1 = grp_model1.add("checkbox", undefined, "");
    ckb_mod1.value = true;
    var mod1Num = grp_model1.add("statictext", undefined, "1:");
    mod1Num.justify = 'left';
    var sttx_mod1 = grp_model1.add("statictext", undefined, Organ_Trad (organiz_SSB_GlobalsDatas.sttx_mod1_str));
    sttx_mod1.characters = 5;
    sttx_mod1.justify = 'right';
    var edtx_mod1 = grp_model1.add("edittext", undefined, "");
    edtx_mod1.characters = 15;
    var checkMark_mod1 = grp_model1.add("statictext", undefined, "☺");
    var save_mod1_but = grp_model1.add("button", undefined, "▼");
    save_mod1_but.size = [20, 20];
    var verify_mod1_but = grp_model1.add("button", undefined, "Ø");
    verify_mod1_but.size = [20, 20];
    // separateur
    separateur = mod_grp.add("panel");
    separateur.alignment = 'fill';
    separateur.margins = [0,2,0,2];
// model 2
var grp_model2 = mod_grp.add("group");
grp_model2.orientation = 'row';
grp_model2.spacing = 5;
grp_model2.margins = [0,2,0,2];
grp_model2.alignChildren = ['left', 'center'];
    var ckb_mod2 = grp_model2.add("checkbox", undefined, "2:");
    var sttx_mod2 = grp_model2.add("statictext", undefined, "");
    sttx_mod2.characters = 5;
    sttx_mod2.justify = 'right';
    var edtx_mod2 = grp_model2.add("edittext", undefined, "");
    edtx_mod2.characters = 15;
    var checkMark_mod2 = grp_model2.add("statictext", undefined, "☺");
    var save_mod2_but = grp_model2.add("button", undefined, "▼");
    save_mod2_but.size = [20, 20];
    var verify_mod2_but = grp_model2.add("button", undefined, "Ø");
    verify_mod2_but.size = [20, 20];
// model 3
var grp_model3 = mod_grp.add("group");
grp_model3.orientation = 'row';
grp_model3.spacing = 5;
grp_model3.margins = [0,2,0,2];
grp_model3.alignChildren = ['left', 'center'];
    var ckb_mod3 = grp_model3.add("checkbox", undefined, "3:");
    var sttx_mod3 = grp_model3.add("statictext", undefined, "");
    sttx_mod3.characters = 5;
    sttx_mod3.justify = 'right';
    var edtx_mod3 = grp_model3.add("edittext", undefined, "");
    edtx_mod3.characters = 15;
    var checkMark_mod3 = grp_model3.add("statictext", undefined, "☺");
    var save_mod3_but = grp_model3.add("button", undefined, "▼");
    save_mod3_but.size = [20, 20];
    var verify_mod3_but = grp_model3.add("button", undefined, "Ø");
    verify_mod3_but.size = [20, 20];
// model 4
var grp_model4 = mod_grp.add("group");
grp_model4.orientation = 'row';
grp_model4.spacing = 5;
grp_model4.margins = [0,2,0,2];
grp_model4.alignChildren = ['left', 'center'];
    var ckb_mod4 = grp_model4.add("checkbox", undefined, "4:");
    var sttx_mod4 = grp_model4.add("statictext", undefined, "");
    sttx_mod4.characters = 5;
    sttx_mod4.justify = 'right';
    var edtx_mod4 = grp_model4.add("edittext", undefined, "");
    edtx_mod4.characters = 15;
    var checkMark_mod4 = grp_model4.add("statictext", undefined, "☺");
    var save_mod4_but = grp_model4.add("button", undefined, "▼");
    save_mod4_but.size = [20, 20];
    var verify_mod4_but = grp_model4.add("button", undefined, "Ø");
    verify_mod4_but.size = [20, 20];
// model 5
var grp_model5 = mod_grp.add("group");
grp_model5.orientation = 'row';
grp_model5.spacing = 5;
grp_model5.margins = [0,2,0,2];
grp_model5.alignChildren = ['left', 'center'];
    var ckb_mod5 = grp_model5.add("checkbox", undefined, "5:");
    var sttx_mod5 = grp_model5.add("statictext", undefined, "");
    sttx_mod5.characters = 5;
    sttx_mod5.justify = 'right';
    var edtx_mod5 = grp_model5.add("edittext", undefined, "");
    edtx_mod5.characters = 15;
    var checkMark_mod5 = grp_model5.add("statictext", undefined, "☺");
    var save_mod5_but = grp_model5.add("button", undefined, "▼");
    save_mod5_but.size = [20, 20];
    var verify_mod5_but = grp_model5.add("button", undefined, "Ø");
    verify_mod5_but.size = [20, 20];
// groupe de validation
var val_grp = scriptWin.add("group");
val_grp.orientation = 'row';
val_grp.spacing = 2;
val_grp.margins = [-5,5,5,5];
val_grp.alignChildren = ['center','top'];
    //---| |
    //---V
    tiret = val_grp.add("statictext", undefined, "__");
    tiret.enabled = false;
var scripter_but = val_grp.add("button", undefined, "Scripter");
scripter_but.size = [55,24];
var info_but = val_grp.add("button", undefined, "?");
info_but.size = [24,24];

// ------------------------------------------------------------------------------------------------ fin  UI --------------------------------------------------------------------------------- //
// manager l'UI
    ckb_mod1.enabled = false;
    checkMark_mod1.visible = checkMark_mod2.visible = checkMark_mod3.visible = checkMark_mod4.visible = checkMark_mod5.visible = false;
    manageMod_grps ();
    ckb_mod2.onClick = ckb_mod3.onClick = ckb_mod4.onClick = ckb_mod5.onClick = activateModel_grp;
    save_mod1_but.helpTip = save_mod2_but.helpTip = save_mod3_but.helpTip = save_mod4_but.helpTip = save_mod5_but.helpTip =
    Organ_Trad (organiz_SSB_GlobalsDatas.memoHelpTip_str);
    verify_mod1_but.helpTip = verify_mod2_but.helpTip = verify_mod3_but.helpTip = verify_mod4_but.helpTip = verify_mod5_but.helpTip =
    Organ_Trad (organiz_SSB_GlobalsDatas.verifyHelpTip_str);
    scriptWin.show();
// ------------ variables globales
var m1_folderdata = new Array;
var m2_folderdata = new Array;
var m3_folderdata = new Array;
var m4_folderdata = new Array;
var m5_folderdata = new Array;

var Proj = app.project;

var alertMsg_modName = 
Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_modName_str);
var alertMsg_emptyMod =
Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_emptyMod_str);
var alertMsg_noModSaved =
Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_noModSaved_str);
var alertMsg_cantPerformScripting =
Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_cantPerformScripting_str);
var alertMsg_cantCreatFile =
Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_cantCreatFile_str);
var alertMsg_fileStrError =
Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_fileStrError_str);
var alertMsg_info =
Organ_Trad (organiz_SSB_GlobalsDatas.alertMsg_info_str);

// -------------------------------------------------- début des fonctions ------------------------------------------- //

function save (m_folderdata, bouton)
{
    var Proj = app.project;
 for (i=1; i<bouton.parent.children.length; i++)
    {
        if ( (bouton.parent.children[i] instanceof EditText)&&(bouton.parent.children[i].text == "") )
        {
            alert(alertMsg_modName, scriptName+scriptVersion);
            return;
        }
 }
 if (Proj.numItems == 0)
 {
     alert(alertMsg_emptyMod, scriptName+scriptVersion);
     return;
 }

    if (m_folderdata.length!=0) m_folderdata.splice(0, m_folderdata.length);
    for (i = 1; i<=Proj.numItems; i++)
    {
        folderType = ((Proj.item(i).parentFolder.name == "Premier niveau")||(Proj.item(i).parentFolder.name == "Root")) ? true : false; //0
        folderName = Proj.item(i).name;                                                                          //1
        folderParent = Proj.item(i).parentFolder.name;                                                     //2
        folderLabel = Proj.item(i).label;                                                                          //3
        m_folderdata[i-1] = [folderType, folderName, folderParent, folderLabel];
    }
    if (bouton.parent == grp_model1) checkMark_mod1.visible = true;
    if (bouton.parent == grp_model2) checkMark_mod2.visible = true;
    if (bouton.parent == grp_model3) checkMark_mod3.visible = true;
    if (bouton.parent == grp_model4) checkMark_mod4.visible = true;
    if (bouton.parent == grp_model5) checkMark_mod5.visible = true;
}

function checkVerif (m_folderdata, boutton)
{
    var Proj = app.project;
    if (m_folderdata.length == 0)
    {
        alert(alertMsg_noModSaved, scriptName+scriptVersion);
        return;
    }
    var modNameforTest;
    for (i=1; i<boutton.parent.children.length; i++)
    {
        if ( (boutton.parent.children[i] instanceof EditText)&&(boutton.parent.children[i].text != "") )
        {
            modNameforTest = boutton.parent.children[i].text;
            break;
        } else { modNameforTest = "modèle sans nom."; }
    }
undogrpTitle = "[test]"+modNameforTest.toString();
app.beginUndoGroup(undogrpTitle);
    if (Proj.numItems != 0){
    for (allItems = Proj.numItems; allItems > 0; allItems--) Proj.item(allItems).remove();
    }

    for(i = 0; i<m_folderdata.length; i++)
    {
        newFolder = Proj.items.addFolder(m_folderdata[i][1]);
        newFolder.label = m_folderdata[i][3];
    }

    for (i = 0; i<m_folderdata.length; i++)
    {
        if (m_folderdata[i][0]) continue;
        var corresp = m_folderdata[i];
        for (j = 1; j<=Proj.numItems; j++)
        {
            if (Proj.item(j).name == corresp[1])
            {
                var currItem = Proj.item(j);
                var parentTargetName = corresp[2];
                for (k = 1; k<=Proj.numItems; k++)
                {
                    if (Proj.item(k).name === parentTargetName)
                    {
                        var parentTarget = Proj.item(k);
                        currItem.parentFolder = parentTarget;
                        continue;
                    }
                }
            }
        }
    }
    for (i = 1; i<=app.project.numItems; i++){app.project.items[i].selected = false};
app.endUndoGroup();
}

function manageMod_grps ()
{
    for (C=2; C<mod_grp.children.length; C++)
    {
        for (c=1; c<mod_grp.children[C].children.length; c++)
        { mod_grp.children[C].children[c].enabled = false; }
    }
}

function activateModel_grp ()
{
    modelGrp = this.parent;
    for (c=1; c<modelGrp.children.length; c++)
    { modelGrp.children[c].enabled = this.value;}
}

function checkBeforeScripting ()
{
    var OK_doIt = false;
    if ( (edtx_mod1 != "")&&(m1_folderdata.length != 0) ) {OK_doIt = true;}else{OK_doIt = false;}
    if (ckb_mod2.value == true) {if ( (edtx_mod2 != "")&&(m2_folderdata.length != 0) ){OK_doIt = true;}else{OK_doIt = false;}}
    if (ckb_mod3.value == true) {if ( (edtx_mod3 != "")&&(m3_folderdata.length != 0) ){OK_doIt = true;}else{OK_doIt = false;}}
    if (ckb_mod4.value == true) {if ( (edtx_mod4 != "")&&(m4_folderdata.length != 0) ){OK_doIt = true;}else{OK_doIt = false;}}
    if (ckb_mod5.value == true) {if ( (edtx_mod5 != "")&&(m5_folderdata.length != 0) ){OK_doIt = true;}else{OK_doIt = false;}}
return OK_doIt;
}

function generateScripts ()
{
    Scripting_precheck = checkBeforeScripting ();
    if (!Scripting_precheck)
    { alert(alertMsg_cantPerformScripting, scriptName+scriptVersion); return;}

check_win = new Window ("palette", scriptName+scriptVersion, undefined, {closeButton:false});
check_winPan = check_win.add("panel", [10, 10, 350, 100]);
check_winPan.add("statictext", [20, 20, 320, 35], "Scripting...");
pgb = check_winPan.add("progressbar", [20, 35, 300, 60], 0, 11);
doneTxt = check_winPan.add("statictext", [70, 20, 300, 130], Organ_Trad (organiz_SSB_GlobalsDatas.doneTxt_str));
doneTxt.graphics.foregroundColor = doneTxt.graphics.newPen(doneTxt.graphics.PenType.SOLID_COLOR, [0.1764705882352941, 0.5490196078431373, 0.9215686274509804], 1);
doneTxt.visible = false;
but_grp = check_win.add("group", [10, 10, 350, 90]);
but_grp_l1 = but_grp.add("group", [0, 0, 335, 40]);
but_grp_l1.alignment = 'row';
but_grp_l1.alignChildren = ['right', 'center'];
but_grp_l1.add("statictext", [67, 2, 320, 35], Organ_Trad (organiz_SSB_GlobalsDatas.exitOption1_str));
but1 = but_grp_l1.add("button", [280, 2, 330, 35], "√");
but1.helpTip = Organ_Trad (organiz_SSB_GlobalsDatas.exitOption1HelpTip_str);
but_grp_l2 = but_grp.add("group", [0, 41, 335, 80]);
but_grp_l2.alignment = 'row';
but_grp_l2.alignChildren = ['right', 'center'];
but_grp_l2.add("statictext", [170, 2, 320, 35], Organ_Trad (organiz_SSB_GlobalsDatas.exitOption2_str));
but2 = but_grp_l2.add("button", [280, 2, 330, 35], "√");
but2.helpTip = Organ_Trad (organiz_SSB_GlobalsDatas.exitOption2HelpTip_str);
but_grp.visible = false;
check_win.center(scriptWin);
scriptWin.hide();
check_win.show();

function pgbUp_steps (pgbVal)
{
    pgb.value = pgbVal;
    check_win.update();
    $.sleep(15);
}
    
var checkSteps = 1;
pgbUp_steps (checkSteps);
    thisScriptName = File($.fileName);
    thisScriptPath = thisScriptName.path;
    pathToWrite = thisScriptPath+"/Startup/";
    newScriptName = "BS_Ørganiz";
    newScriptVersion = "_v2";
    scriptExtension = ".jsx";
    
    var newScript = new File(pathToWrite+newScriptName+newScriptVersion+scriptExtension);
    newScript.open('w');
checkSteps+=1;
pgbUp_steps (checkSteps);

    var buildScriptUI_res1 =
    "#targetengine \"main\";\n"+
    "(function BS_KeepOrganiz (thisObj)\n{\n"+
    "var KO_Win = new Window(\"palette\", \"BS_\\330rganiz_v2\", undefined,{closeButton: false});\n"+
    "var KO_Win_grp1 = KO_Win.add(\"group\");\n"+
    "KO_Win_grp1.orientation = 'column';\n"+
    "KO_Win_grp1.alignChildren = ['center', 'center'];\n"+
    "KO_Win_grp1.spacing = 20;\n"+
    "KO_Win_grp1.add(\"statictext\", undefined, "+Organ_Trad (organiz_SSB_GlobalsDatas.newScriptRes_mainQuestion_str)+");\n"+
    "var ddl_models = KO_Win_grp1.add(\"dropdownlist\", undefined);\n"+
    "ddl_models.size = [130, 30];\n"+
    "ddl_models.itemSize = [100,30];\n"+
    "var KO_Win_grp2 = KO_Win.add(\"group\");\n"+
    "KO_Win_grp2.alignChildren = 'fill';\n"+
    "KO_Win_grp2.margins = [0,20,0,10];\n"+
    "var NO_but = KO_Win_grp2.add(\"button\", undefined, "+Organ_Trad (organiz_SSB_GlobalsDatas.newScriptRes_NObut_str)+");\n"+
    "var OUI_but = KO_Win_grp2.add(\"button\", undefined, "+Organ_Trad (organiz_SSB_GlobalsDatas.newScriptRes_OUIbut_str)+");\n";
    newScript.write(buildScriptUI_res1);
    var completScript_str = buildScriptUI_res1;
checkSteps+=1;
pgbUp_steps (checkSteps);
    var addItem1 = 
    "ddl_models.add ('item',"+"unescape('"+escape(edtx_mod1.text)+"'));\n";
    newScript.write(addItem1);
    completScript_str += addItem1;
checkSteps+=1;
pgbUp_steps (checkSteps);
    for (C=2; C<mod_grp.children.length; C++)
    {
        if (mod_grp.children[C].children[0].value == true)
        {
            itemX = mod_grp.children[C].children[2];
            var addItemX =
            "ddl_models.add ('item',"+"unescape('"+escape(itemX.text)+"'));\n";
            newScript.write(addItemX);
            completScript_str += addItemX;
        }
    }
checkSteps+=1;
pgbUp_steps (checkSteps);
    var buildScriptUI_res2 = 
    "ddl_models.selection = 0;\n"+
    "KO_Win.show();\n\n";
    var nProj = "var Proj = app.project;\n";
    newScript.write(buildScriptUI_res2+nProj);
    completScript_str += buildScriptUI_res2+nProj;
checkSteps+=1;
pgbUp_steps (checkSteps);

    function create_modelFolderData (m_folderdata, numModel)
    {
        var modelFolderData_longStr = "";
        for (i=0; i<m_folderdata.length; i++)
        {
            var tempFolder = "model"+numModel+"_folderData"+(i+1)+" = new Array ("+m_folderdata[i][0]+",unescape(\""+escape(m_folderdata[i][1])+"\"),unescape(\""+escape(m_folderdata[i][2])+"\"),"+m_folderdata[i][3]+");\n";
            modelFolderData_longStr += tempFolder;
        }
        var masterModelFolderData = "var m"+numModel+"_folderdata = new Array (";
        modelFolderData_longStr += masterModelFolderData;
        for (i=0; i<m_folderdata.length; i++)
        {
            modelFolderData_longStr += "model"+numModel+"_folderData"+(i+1)+",";
        }
    modelFolderData_longStr = modelFolderData_longStr.slice(0, modelFolderData_longStr.length-1);
    modelFolderData_longStr += ");\n\n";
    
    newScript.write(modelFolderData_longStr);
    completScript_str += modelFolderData_longStr;
    }

    create_modelFolderData (m1_folderdata, 1);
    if (ckb_mod2.value == true) create_modelFolderData (m2_folderdata, 2);
    if (ckb_mod3.value == true) create_modelFolderData (m3_folderdata, 3);
    if (ckb_mod4.value == true) create_modelFolderData (m4_folderdata, 4);
    if (ckb_mod5.value == true) create_modelFolderData (m5_folderdata, 5);
checkSteps+=1;
pgbUp_steps (checkSteps);

        var nFunction_part1 =
        "function createModel (m_folderdata){\n";
        var nFunction_part2 = "}\n";
        var undo_o =
        "undogrpTitle = \"[\\330rganiz]\"+ddl_models.selection.toString();\n"+
        "app.beginUndoGroup(undogrpTitle);\n";
        var undo_c = "app.endUndoGroup();\n";
        
        var createFolderLoop_str = 
        "for(i = 0; i<m_folderdata.length; i++)\n"+
        "{\n"+
        "newFolder = Proj.items.addFolder(m_folderdata[i][1]);\n"+
        "newFolder.label = m_folderdata[i][3];\n"+
        "}\n";
        
        var retriveParentLoop_str =
        "for (i = 0; i<m_folderdata.length; i++)\n"+
        "{\n"+
        "if (m_folderdata[i][0]) continue;\n"+
        "var corresp = m_folderdata[i];\n"+
        "for (j = 1; j<=Proj.numItems; j++)\n"+
        "{\n"+
        "if (Proj.item(j).name == corresp[1])\n"+
        "{\n"+
        "var currItem = Proj.item(j);\n"+
        "var parentTargetName = corresp[2];\n"+
        "for (k = 1; k<=Proj.numItems; k++)\n"+
        "{\n"+
        "if (Proj.item(k).name === parentTargetName)\n"+
        "{\n"+
        "var parentTarget = Proj.item(k);\n"+
        "currItem.parentFolder = parentTarget;\n"+
        "continue;\n"+
        "}\n"+
        "}\n"+
        "}\n"+
        "}\n"+
        "}\n";
        
    var fonction_longString = nFunction_part1+undo_o+createFolderLoop_str+retriveParentLoop_str+undo_c+nFunction_part2;
    newScript.write(fonction_longString);
    completScript_str += fonction_longString;
checkSteps+=1;
pgbUp_steps (checkSteps);

    var str_doTheJob_click =
    "OUI_but.onClick = function (){\n"+
    "switch (ddl_models.selection.index){\n"+
    "case 0:\n"+
    "   createModel (m1_folderdata);\n"+
    "   break;\n"+
    "case 1:\n"+
    "   createModel (m2_folderdata);\n"+
    "   break;\n"+
    "case 2:\n"+
    "   createModel (m3_folderdata);\n"+
    "   break;\n"+
    "case 3:\n"+
    "   createModel (m4_folderdata);\n"+
    "   break;\n"+
    "case 4:\n"+
    "   createModel (m5_folderdata);\n"+
    "   break;\n"+
    "}\n"+
    "KO_Win.close();\n"+
    "}\n";
    
    var str_exit_click =
    "NO_but.onClick = function (){\n"+
    "KO_Win.close();\n"+
    "return;\n"+
    "}\n"+
    "})(this);";
    
    newScript.write(str_doTheJob_click+str_exit_click);
    completScript_str += str_doTheJob_click+str_exit_click;
checkSteps+=1;
pgbUp_steps (checkSteps);
    newScript.close();
checkSteps+=1;
pgbUp_steps (checkSteps);

    createdScript = File (pathToWrite+newScriptName+newScriptVersion+scriptExtension);
    if (!createdScript.exists)
    {
        alert(alertMsg_cantCreatFile, scriptName+scriptVersion, errorIcon = true);
        check_win.close();
        scriptWin.show();
        return;
    } else {
        createdScript.open('r');
        createdScript_content = createdScript.read ();
        createdScript.close();
        if (createdScript_content === completScript_str)
        {
checkSteps+=1;
pgbUp_steps (checkSteps);
        } else {
        alert(alertMsg_fileStrError, scriptName+scriptVersion, errorIcon = true);
        check_win.close();
        scriptWin.show();
        return;
        }
    }
    
    if (pgb.value == 11)
    {
        doneTxt.visible = true;
        but_grp.visible = true;
    }
    
    but1.onClick = function (){
        this.window.close();
        scriptWin.close();
        app.activate();
    }

    but2.onClick = function (){
        this.window.close();
        scriptWin.close();
        app.project.close(CloseOptions.DO_NOT_SAVE_CHANGES);
        app.quit();
    }
}
// -------------------------------------------------- fin des fonctions ------------------------------------------- //
// ------------------------------------------------------------------------------------------------------- function's callBacks
save_mod1_but.onClick = function () {save (m1_folderdata, this) };
verify_mod1_but.onClick = function () {checkVerif (m1_folderdata, this) };
save_mod2_but.onClick = function () {save (m2_folderdata, this) };
verify_mod2_but.onClick = function () {checkVerif (m2_folderdata, this) };
save_mod3_but.onClick = function () {save (m3_folderdata, this) };
verify_mod3_but.onClick = function () {checkVerif (m3_folderdata, this) };
save_mod4_but.onClick = function () {save (m4_folderdata, this) };
verify_mod4_but.onClick = function () {checkVerif (m4_folderdata, this) };
save_mod5_but.onClick = function () {save (m5_folderdata, this) };
verify_mod5_but.onClick = function () {checkVerif (m5_folderdata, this) };

scripter_but.onClick = generateScripts;
info_but.onClick = function(){alert(alertMsg_info, "Infos!")}
// fin du script
}
if ((app.isoLanguage == "fr_FR")||(app.isoLanguage == "en_EN")||(app.isoLanguage == "en_US"))
{
    KeepOrganiz_StartupScriptBuilder (this);
} else {
    alert("Désolé mais ce script requiert qu'After Effects soit installé en Fançais ou en Anglais.\n"+
            "\n"+
            "Sorry but this script works only for French or English versions of After Effects.", "StartupScriptBuilder", errorIcon = true);
}
}